﻿using Microsoft.Win32;
using Syncfusion.UI.Xaml.Charts;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ExportChart
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            Print(grid);
        }

        /// <summary>
        /// To print the visual element using chart dialog box
        /// </summary>
        /// <param name="visual">visual element</param>
        public void Print(Panel visual)
        {
            //To print the visual using chart print dialog box
            ChartPrintDialog printDialog = new ChartPrintDialog();
            PrintingEventArgs args = new PrintingEventArgs() { PrintDialog = printDialog, PrintVisual = printDialog.GetPrintVisual(visual) };

            if (args.ShowPrintDialog)
            {
                bool retValue = (bool)printDialog.ShowPrintDialog(visual, Rect.Empty, visual.ActualHeight, visual.ActualWidth);
                Keyboard.Focus(visual);
            }

            else if (!args.CancelPrinting)
            {
                PrintDialog pd = new PrintDialog();
                pd.PrintVisual(visual, "Chart is printing");
            }

        }

        private void Button_Click_1(object sender, RoutedEventArgs e)
        {
            Save(grid);
        }


        /// <summary>
        /// To save the visual element as image
        /// </summary>
        /// <param name="grid">visual element</param>
        private void Save(Panel grid)
        {
            //To save the file using dialog box
            SaveFileDialog saveDialog = new SaveFileDialog();
            saveDialog.Filter = "Bitmap(*.bmp)|*.bmp|JPEG(*.jpg,*.jpeg)|*.jpg;*.jpeg|Gif (*.gif)|*.gif|PNG(*.png)|*.png|All files (*.*)|*.*";
            if(saveDialog.ShowDialog()==true)
            {
                var imageExtension = new FileInfo(saveDialog.SafeFileName).Extension.ToLower(System.Globalization.CultureInfo.InvariantCulture);
                BitmapEncoder imgEncoder = null;
                switch (imageExtension)
                {
                    case ".bmp":
                        imgEncoder = new BmpBitmapEncoder();
                        break;
                    case ".jpg":
                    case ".jpeg":
                        imgEncoder = new JpegBitmapEncoder();
                        break;
                    case ".png":
                        imgEncoder = new PngBitmapEncoder();
                        break;
                    case ".gif":
                        imgEncoder = new GifBitmapEncoder();
                        break;
                    case ".tif":
                    case ".tiff":
                        imgEncoder = new TiffBitmapEncoder();
                        break;
                    case ".wdp":
                        imgEncoder = new WmpBitmapEncoder();
                        break;
                    default:
                        imgEncoder = new BmpBitmapEncoder();
                        break;
                }

                if (grid != null)
                {
                    //Converts visual element to bitmap
                    RenderTargetBitmap bmpSource = new RenderTargetBitmap((int)grid.ActualWidth, (int)grid.ActualHeight, 96, 96, PixelFormats.Pbgra32);
                    bmpSource.Render(grid);
                    imgEncoder.Frames.Add(BitmapFrame.Create(bmpSource));
                    using (Stream stream = saveDialog.OpenFile())
                    {
                        imgEncoder.Save(stream);
                        stream.Close();
                    }
                }
            }
        }
    }

    public class Model
    {
        public double XData { get; set; }

        public double YData { get; set; }

        public double YData1 { get; set; }

        public double YData2 { get; set; }
        
        public double YData3 { get; set; }
    }

    public class ViewModel
    {

        public ViewModel()
        {
            Datas = new ObservableCollection<Model>();
            Datas1 = new ObservableCollection<Model>();
            Datas.Add(new Model() { XData = 0, YData = 10, YData1 = 13, YData2 = 17, YData3 = 22 });
            Datas.Add(new Model() { XData = 1, YData = 15, YData1 = 18, YData2 = 21, YData3 = 25 });
            Datas.Add(new Model() { XData = 2, YData = 13, YData1 = 15, YData2 = 18, YData3 = 21 });
            Datas.Add(new Model() { XData = 3, YData = 18, YData1 = 20, YData2 = 23, YData3 = 25 });
            Datas.Add(new Model() { XData = 4, YData = 16, YData1 = 18, YData2 = 20, YData3 = 22 });
            Datas.Add(new Model() { XData = 5, YData = 23, YData1 = 25, YData2 = 28, YData3 = 30 });
            Datas.Add(new Model() { XData = 6, YData = 12, YData1 = 15, YData2 = 18, YData3 = 20 });
            Datas.Add(new Model() { XData = 7, YData = 20, YData1 = 22, YData2 = 25, YData3 = 28 });

            Datas1.Add(new Model() { XData = 5, YData = 23, YData1 = 25, YData2 = 28, YData3 = 30 });
            Datas1.Add(new Model() { XData = 6, YData = 12, YData1 = 15, YData2 = 18, YData3 = 20 });
            Datas1.Add(new Model() { XData = 7, YData = 20, YData1 = 22, YData2 = 25, YData3 = 28 });
            Datas1.Add(new Model() { XData = 2, YData = 13, YData1 = 15, YData2 = 18, YData3 = 21 });
            Datas1.Add(new Model() { XData = 3, YData = 18, YData1 = 20, YData2 = 23, YData3 = 25 });
        }

        public ObservableCollection<Model> Datas { get; set; }

        public ObservableCollection<Model> Datas1 { get; set; }
    }
}
